summaryrefslogtreecommitdiff
path: root/src/select/computed.c
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2021-03-22 17:47:11 +0000
committerMichael Drake <tlsa@netsurf-browser.org>2021-05-19 14:40:54 +0100
commitecf42afc3329b03ee642ede84f9ba224d2aff1e1 (patch)
treef147bfabd58888c1f9fd2bd98c14b840314eb5ed /src/select/computed.c
parent65d4fd6e83d421e7fa7a8c7df44d01797e3c69ae (diff)
downloadlibcss-ecf42afc3329b03ee642ede84f9ba224d2aff1e1.tar.gz
libcss-ecf42afc3329b03ee642ede84f9ba224d2aff1e1.tar.bz2
Selection: Don't duplicate unit conversion members in media descriptor.
Diffstat (limited to 'src/select/computed.c')
-rw-r--r--src/select/computed.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/select/computed.c b/src/select/computed.c
index d075af9..c019590 100644
--- a/src/select/computed.c
+++ b/src/select/computed.c
@@ -248,7 +248,7 @@ css_error css__computed_style_initialise(css_computed_style *style,
css_error css_computed_style_compose(
const css_computed_style *restrict parent,
const css_computed_style *restrict child,
- const css_unit_len_ctx *unit_len_ctx,
+ const css_unit_ctx *unit_ctx,
css_computed_style **restrict result)
{
css_computed_style *composed;
@@ -274,7 +274,7 @@ css_error css_computed_style_compose(
}
/* Finally, compute absolute values for everything */
- error = css__compute_absolute_values(parent, composed, unit_len_ctx);
+ error = css__compute_absolute_values(parent, composed, unit_ctx);
if (error != CSS_OK) {
return error;
}
@@ -1085,12 +1085,12 @@ uint8_t css_computed_order(const css_computed_style *style,
*
* \param parent Parent style, or NULL for tree root
* \param style Computed style to process
* \param unit_len_ctx Client length conversion context.
* \return CSS_OK on success.
*/
css_error css__compute_absolute_values(const css_computed_style *parent,
css_computed_style *style,
- const css_unit_len_ctx *unit_len_ctx)
+ const css_unit_ctx *unit_ctx)
{
css_hint_length *ref_length = NULL;
css_hint psize, size, ex_size;
@@ -1112,8 +1112,8 @@ css_error css__compute_absolute_values(const css_computed_style *parent,
&size.data.length.unit);
error = css_unit_compute_absolute_font_size(ref_length,
- unit_len_ctx->root_style,
- unit_len_ctx->font_size_default,
+ unit_ctx->root_style,
+ unit_ctx->font_size_default,
&size);
if (error != CSS_OK)
return error;
@@ -1131,8 +1131,8 @@ css_error css__compute_absolute_values(const css_computed_style *parent,
error = css_unit_compute_absolute_font_size(
&size.data.length,
- unit_len_ctx->root_style,
- unit_len_ctx->font_size_default,
+ unit_ctx->root_style,
+ unit_ctx->font_size_default,
&ex_size);
if (error != CSS_OK)
return error;
@@ -1085,12 +1085,12 @@ uint8_t css_computed_order(const css_computed_style *style,
* \param parent Parent style, or NULL for tree root
* \param style Computed style to process
- * \param unit_len_ctx Client length conversion context.
+ * \param unit_ctx Client length conversion context.
* \return CSS_OK on success.
*/